Closes the buffer and releases the underlying shared memory.
Examples
# \donttest{
buf <- buffer("double", dim = 10)
buffer_close(buf)
# }
Closes the buffer and releases the underlying shared memory.
# \donttest{
buf <- buffer("double", dim = 10)
buffer_close(buf)
# }