Returns per-process counters for shard buffer reads and writes. shard_map uses write counters internally to report write volume/operations in copy_report().
Returns per-process counters for shard buffer reads and writes. shard_map uses write counters internally to report write volume/operations in copy_report().