| in_arena | R Documentation |
Returns TRUE if the current execution context is within an arena() scope.
in_arena()
Logical indicating whether we are in an arena scope.
in_arena()
arena({
in_arena()
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.