| row_layout | R Documentation |
Computes disjoint row ranges for each shard via prefix-sum, enabling lock-free writes where each shard writes to a unique region.
row_layout(shards, rows_per_shard)
shards |
A |
rows_per_shard |
Either a scalar integer or a function(shard)->integer. |
A named list mapping shard id (character) to an idx_range(start, end).
sh <- shards(100, block_size = 25)
layout <- row_layout(sh, rows_per_shard = 25L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.