schema: Define a table schema

View source: R/tables.R

schemaR Documentation

Define a table schema

Description

A schema is a named set of columns with explicit types. It is used to allocate table buffers and validate writes.

Usage

schema(...)

Arguments

...

Named columns with type specs (e.g., int32(), float64()).

Value

A shard_schema object.

Examples

s <- schema(x = float64(), y = int32(), label = string_col())
s

shard documentation built on April 3, 2026, 9:08 a.m.