Intended to be called inside a worker process (e.g., via clusterCall()).
On unsupported platforms, returns FALSE.
Examples
affinity_supported()
#> [1] TRUE
Intended to be called inside a worker process (e.g., via clusterCall()).
On unsupported platforms, returns FALSE.
affinity_supported()
#> [1] TRUE