| shard_register_adapter | R Documentation |
Registers a custom adapter for a specific class. When deep sharing encounters
an object of this class, it will use the adapter's children() function
to extract shareable components instead of generic traversal.
shard_register_adapter(class, adapter)
class |
A character string naming the class to register the adapter for. |
adapter |
A list containing:
|
Invisibly returns the previous adapter for this class (if any), or NULL if no adapter was registered.
shard_list_adapters()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.