shard_unregister_adapter: Unregister an Adapter

View source: R/adapter.R

shard_unregister_adapterR Documentation

Unregister an Adapter

Description

Removes a previously registered adapter for a class. After unregistration, objects of this class will use default traversal behavior during deep sharing.

Usage

shard_unregister_adapter(class)

Arguments

class

A character string naming the class to unregister.

Value

Invisibly returns the removed adapter, or NULL if no adapter was registered for this class.

Examples

shard_list_adapters()

shard documentation built on April 3, 2026, 9:08 a.m.