Learn R Programming

shard (version 0.1.0)

idx_range: Contiguous index range

Description

Creates a compact, serializable range descriptor for contiguous indices. This avoids allocating an explicit index vector for large slices.

Usage

idx_range(start, end)

Value

An object of class shard_idx_range.

Arguments

start

Integer. Start index (1-based, inclusive).

end

Integer. End index (1-based, inclusive).

Examples

Run this code
r <- idx_range(1, 100)
r

Run the code above in your browser using DataLab