powered by
Creates a compact, serializable range descriptor for contiguous indices. This avoids allocating an explicit index vector for large slices.
idx_range(start, end)
An object of class shard_idx_range.
shard_idx_range
Integer. Start index (1-based, inclusive).
Integer. End index (1-based, inclusive).
r <- idx_range(1, 100) r
Run the code above in your browser using DataLab