Learn R Programming

shard (version 0.1.0)

in_arena: Check if Currently Inside an Arena

Description

Returns TRUE if the current execution context is within an arena() scope.

Usage

in_arena()

Arguments

Value

Logical indicating whether we are in an arena scope.

Examples

Run this code
in_arena()
arena({
  in_arena()
})

Run the code above in your browser using DataLab