powered by
Returns TRUE if the current execution context is within an arena() scope.
in_arena()
Logical indicating whether we are in an arena scope.
in_arena() arena({ in_arena() })
Run the code above in your browser using DataLab