| pool_health_check | R Documentation |
Monitors all workers, recycling those with excessive RSS drift or that have died.
pool_health_check(pool = NULL, busy_workers = NULL)
pool |
A |
busy_workers |
Optional integer vector of worker ids that are currently running tasks (used internally by the dispatcher to avoid recycling a worker while a result is in flight). |
A list with health status per worker and actions taken.
p <- pool_create(2)
pool_health_check(p)
pool_stop(p)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.