A list with health status per worker and actions taken.
Arguments
pool
A shard_pool object. If NULL, uses the current pool.
busy_workers
Optional integer vector of worker ids that are currently
running tasks (used internally by the dispatcher to avoid recycling a worker
while a result is in flight).