A schema is a named set of columns with explicit types. It is used to allocate table buffers and validate writes.
Examples
s <- schema(x = float64(), y = int32(), label = string_col())
s
#> $columns
#> $columns$x
#> $kind
#> [1] "float64"
#>
#> attr(,"class")
#> [1] "shard_coltype"
#>
#> $columns$y
#> $kind
#> [1] "int32"
#>
#> attr(,"class")
#> [1] "shard_coltype"
#>
#> $columns$label
#> $kind
#> [1] "string"
#>
#> attr(,"class")
#> [1] "shard_coltype"
#>
#>
#> attr(,"class")
#> [1] "shard_schema"