| schema | R Documentation |
A schema is a named set of columns with explicit types. It is used to allocate table buffers and validate writes.
schema(...)
... |
Named columns with type specs (e.g., |
A shard_schema object.
s <- schema(x = float64(), y = int32(), label = string_col())
s
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.