Learn R Programming

shard (version 0.1.0)

schema: Define a table schema

Description

A schema is a named set of columns with explicit types. It is used to allocate table buffers and validate writes.

Usage

schema(...)

Value

A shard_schema object.

Arguments

...

Named columns with type specs (e.g., int32(), float64()).

Examples

Run this code
s <- schema(x = float64(), y = int32(), label = string_col())
s

Run the code above in your browser using DataLab