powered by
A schema is a named set of columns with explicit types. It is used to allocate table buffers and validate writes.
schema(...)
A shard_schema object.
shard_schema
Named columns with type specs (e.g., int32(), float64()).
int32()
float64()
s <- schema(x = float64(), y = int32(), label = string_col()) s
Run the code above in your browser using DataLab