Skip to contents

Removes a previously registered adapter for a class. After unregistration, objects of this class will use default traversal behavior during deep sharing.

Usage

shard_unregister_adapter(class)

Arguments

class

A character string naming the class to unregister.

Value

Invisibly returns the removed adapter, or NULL if no adapter was registered for this class.

Examples

shard_list_adapters()
#> character(0)