| shard_unregister_adapter | R Documentation |
Removes a previously registered adapter for a class. After unregistration, objects of this class will use default traversal behavior during deep sharing.
shard_unregister_adapter(class)
class |
A character string naming the class to unregister. |
Invisibly returns the removed adapter, or NULL if no adapter was registered for this class.
shard_list_adapters()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.