Learn R Programming

shard (version 0.1.0)

shard_unregister_adapter: Unregister an Adapter

Description

Removes a previously registered adapter for a class. After unregistration, objects of this class will use default traversal behavior during deep sharing.

Usage

shard_unregister_adapter(class)

Value

Invisibly returns the removed adapter, or NULL if no adapter was registered for this class.

Arguments

class

A character string naming the class to unregister.

Examples

Run this code
shard_list_adapters()

Run the code above in your browser using DataLab