| share_open | R Documentation |
Opens a shared object that was created by another process. This is useful
for workers that need to attach to shared data without having the original
shard_shared object.
share_open(path, backing = c("mmap", "shm"), size = NULL)
path |
Path to the shared segment. |
backing |
Backing type: "mmap" or "shm". |
size |
Size of the segment in bytes. If NULL, attempts to detect. |
A shard_shared object attached to the existing segment.
shared <- share(1:50)
info <- shared_info(shared)
reopened <- share_open(info$path, backing = "mmap")
close(reopened)
close(shared)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.