powered by
Opens a shared object that was created by another process. This is useful for workers that need to attach to shared data without having the original shard_shared object.
shard_shared
share_open(path, backing = c("mmap", "shm"), size = NULL)
A shard_shared object attached to the existing segment.
Path to the shared segment.
Backing type: "mmap" or "shm".
Size of the segment in bytes. If NULL, attempts to detect.
# \donttest{ shared <- share(1:50) info <- shared_info(shared) reopened <- share_open(info$path, backing = "mmap") close(reopened) close(shared) # }
Run the code above in your browser using DataLab