stream_map: Stream over row-groups/datasets and map
Description
Applies f() to each partition and returns the list of per-partition results.
This is still much cheaper than collecting the full dataset when f() returns
a small summary per partition.
Usage
stream_map(x, f, ...)
# S3 method for shard_row_groups
stream_map(x, f, ...)
# S3 method for shard_dataset
stream_map(x, f, ...)
Value
A list of per-partition values, one element per row-group file.